"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.validate = exports.addToSchema = exports.DIRECTIVES = exports.plugin = void 0;
const tslib_1 = require("tslib");
const plugin_helpers_1 = require("@graphql-codegen/plugin-helpers");
const path_1 = require("path");
const graphql_tag_1 = tslib_1.__importDefault(require("graphql-tag"));
const visitor_1 = require("./visitor");
const config_1 = require("./config");
const plugin = (schema, documents, config) => {
    const visitor = new visitor_1.TsMongoVisitor(schema, config);
    const astNode = (0, plugin_helpers_1.getCachedDocumentNodeFromSchema)(schema);
    const visitorResult = (0, plugin_helpers_1.oldVisit)(astNode, { leave: visitor });
    const header = visitor.objectIdImport;
    const res = [header, ...visitorResult.definitions.filter(d => typeof d === 'string')].join('\n');
    return res;
};
exports.plugin = plugin;
exports.DIRECTIVES = (0, graphql_tag_1.default) `
  directive @${config_1.Directives.UNION}(additionalFields: [AdditionalEntityFields], discriminatorField: String) on UNION
  directive @${config_1.Directives.ABSTRACT_ENTITY}(discriminatorField: String!, additionalFields: [AdditionalEntityFields]) on INTERFACE
  directive @${config_1.Directives.CHIMP}(additionalFields: [AdditionalEntityFields], embedded: Boolean) on OBJECT
  directive @${config_1.Directives.COLUMN}(overrideType: String) on FIELD_DEFINITION
  directive @${config_1.Directives.COMPUTED} on FIELD_DEFINITION | OBJECT
  directive @${config_1.Directives.ID} on FIELD_DEFINITION
  directive @${config_1.Directives.LINK}(overrideType: String) on FIELD_DEFINITION
  directive @${config_1.Directives.EMBEDDED} on FIELD_DEFINITION
  directive @${config_1.Directives.MAP}(path: String!) on FIELD_DEFINITION
  # Inputs
  input AdditionalEntityFields {
    path: String
    type: String
  }
`;
exports.addToSchema = exports.DIRECTIVES;
const validate = (schema, documents, config, outputFile) => tslib_1.__awaiter(void 0, void 0, void 0, function* () {
    if ((0, path_1.extname)(outputFile) !== '.ts' && (0, path_1.extname)(outputFile) !== '.tsx') {
        throw new Error(`Plugin "typescript-mongodb" requires extension to be ".ts" or ".tsx"!`);
    }
});
exports.validate = validate;
//# sourceMappingURL=index.js.map